@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2016-02-04'; # DATE
-our $VERSION = '1.38'; # VERSION
+our $DATE = '2016-02-26'; # DATE
+our $VERSION = '1.39'; # VERSION
 
 use 5.010001;
 use strict;
@@ -890,6 +890,31 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                 ],
             }, # cmdline_src (stdin_or_files)
 
+            {
+                name => 'cmdline_src (stdin_or_args)',
+                before_all_tests => sub {
+                },
+                tests => [
+                    {
+                        tags        => ['cmdline_src', 'cmdline_src:stdin_or_args'],
+                        name        => 'from arg',
+                        gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_args_array"},
+                        inline_gen_args => {load_module=>['Perinci::Examples::CmdLineSrc']},
+                        argv        => ['--a1', "x"],
+                        stdout_like => qr/a1=\[x\]/,
+                    },
+                    {
+                        tags        => ['cmdline_src', 'cmdline_src:stdin_or_args'],
+                        name        => 'from stdin',
+                        gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_args_array"},
+                        inline_gen_args => {load_module=>['Perinci::Examples::CmdLineSrc']},
+                        argv        => [],
+                        stdin       => "bar\nbaz",
+                        stdout_like => qr/a1=\[bar,baz\]/,
+                    },
+                ],
+            }, # cmdline_src (stdin_or_args)
+
             {
                 name => 'dry-run',
                 tests => [
@@ -1472,7 +1497,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.38 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-02-04.
+This document describes version 1.39 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-02-26.
 
 =head1 FUNCTIONS
 
